@@ -1,10 +1,16 @@
 import config from 'config';
 
+import { SendStatusToMetaServer } from '@tamanu/shared/tasks/SendStatusToMetaServer';
+
 // import { SenaitePoller } from './SenaitePoller';
 import { MedicationDiscontinuer } from './MedicationDiscontinuer';
 import { RefreshUpcomingVaccinations } from './RefreshMaterializedView';
 
-const DEFAULT_TASK_CLASSES = [MedicationDiscontinuer, RefreshUpcomingVaccinations];
+const DEFAULT_TASK_CLASSES = [
+  MedicationDiscontinuer,
+  RefreshUpcomingVaccinations,
+  SendStatusToMetaServer,
+];
 
 export function startScheduledTasks(context, taskClasses) {
   if (config.senaite.enabled) {
@@ -13,8 +19,8 @@ export function startScheduledTasks(context, taskClasses) {
     // senaite.beginPolling();
   }
 
-  const tasks = (taskClasses || DEFAULT_TASK_CLASSES).map(Task => new Task(context));
+  const tasks = (taskClasses || DEFAULT_TASK_CLASSES).map((Task) => new Task(context));
 
-  tasks.forEach(t => t.beginPolling());
-  return () => tasks.forEach(t => t.cancelPolling());
+  tasks.forEach((t) => t.beginPolling());
+  return () => tasks.forEach((t) => t.cancelPolling());
 }
