@@ -209,11 +209,9 @@ const DischargeSummaryPrintoutComponent = ({
   patientConditions,
   certificateData,
   getLocalisation,
-  getTranslation,
   getSetting,
 }) => {
   const { logo } = certificateData;
-  const clinicianText = getTranslation('general.localisedField.clinician.label.short', 'Clinician');
   const { diagnoses, procedures, medications } = encounter;
   const visibleDiagnoses = diagnoses.filter(
     ({ certainty }) => !DIAGNOSIS_CERTAINTIES_TO_HIDE.includes(certainty),
@@ -221,7 +219,11 @@ const DischargeSummaryPrintoutComponent = ({
   const primaryDiagnoses = visibleDiagnoses.filter(d => d.isPrimary);
   const secondaryDiagnoses = visibleDiagnoses.filter(d => !d.isPrimary);
   const notes = discharge?.note;
-  const { facilityName, facilityAddress, facilityTown } = discharge;
+  const {
+    name: facilityName,
+    address: facilityAddress,
+    town: facilityTown,
+  } = discharge.address;
 
   // change header if facility details are present in discharge
   if (facilityName && facilityAddress && certificateData?.title) {
@@ -246,11 +248,7 @@ const DischargeSummaryPrintoutComponent = ({
           <PatientDetailsWithAddress patient={patientData} getLocalisation={getLocalisation} />
         </SectionContainer>
         <SectionContainer>
-          <EncounterDetailsExtended
-            encounter={encounter}
-            discharge={discharge}
-            clinicianText={clinicianText}
-          />
+          <EncounterDetailsExtended encounter={encounter} discharge={discharge} />
         </SectionContainer>
         <SectionContainer>
           {patientConditions.length > 0 && (
